cache

package
v1.0.110 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2026 License: LGPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	DisableCache bool
)

Functions

func GetAppName

func GetAppName(appID string) (string, bool)

GetAppName looks up a cached Steam AppID title.

func GetHubcapZIP

func GetHubcapZIP(appID uint32) ([]byte, bool)

GetHubcapZIP retrieves cached Hubcap ZIP archive bytes if available on disk.

func GetNews

func GetNews(appID string) (string, bool)

GetNews retrieves cached Steam patch notes if less than 24 hours old.

func SaveAppName

func SaveAppName(appID, name string)

SaveAppName saves a Steam AppID title to local disk cache.

func SaveHubcapZIP

func SaveHubcapZIP(appID uint32, data []byte) error

SaveHubcapZIP writes Hubcap ZIP archive bytes to local disk cache.

func SaveNews

func SaveNews(appID, news string)

SaveNews caches Steam patch notes to disk for 24 hours.

Types

type AppNameCache

type AppNameCache struct {
	Names map[string]string `json:"names"`
}

type CachedNews

type CachedNews struct {
	Timestamp time.Time `json:"timestamp"`
	News      string    `json:"news"`
}

Jump to